@@ -4,7 +4,7 @@ import os
 
 # Local library
 import pyblish.backend.lib
-import pyblish
+import pyblish.backend.plugin
 
 # from pyblish.vendor.nose.tools import raises
 
@@ -15,14 +15,20 @@ FAMILY = 'test.family'
 package_path = pyblish.backend.lib.main_package_path()
 plugin_path = os.path.join(package_path, 'backend', 'tests', 'plugins')
 
-pyblish.deregister_all()
-pyblish.register_plugin_path(plugin_path)
+pyblish.backend.plugin.deregister_all()
+pyblish.backend.plugin.register_plugin_path(plugin_path)
+
+
+def test_singleton():
+    """Context is a singleton"""
+    ctx = pyblish.backend.plugin.Context()
+    assert ctx is pyblish.backend.plugin.Context()
 
 
 def test_data():
     """The data() interface works"""
 
-    ctx = pyblish.Context()
+    ctx = pyblish.backend.plugin.Context()
 
     # Not passing a key returns all data as a dict,
     # but there is none yet.
@@ -40,17 +46,17 @@ def test_data():
 
 def test_add_remove_instances():
     """Adding instances to context works"""
-    ctx = pyblish.Context()
-    inst = pyblish.Instance(name='Test', parent=ctx)
+    ctx = pyblish.backend.plugin.Context()
+    inst = pyblish.backend.plugin.Instance(name='Test', parent=ctx)
     ctx.add(inst)
     ctx.remove(inst)
 
 
 def test_instance_equality():
     """Instance equality works"""
-    inst1 = pyblish.Instance('Test1')
-    inst2 = pyblish.Instance('Test2')
-    inst3 = pyblish.Instance('Test2')
+    inst1 = pyblish.backend.plugin.Instance('Test1')
+    inst2 = pyblish.backend.plugin.Instance('Test2')
+    inst3 = pyblish.backend.plugin.Instance('Test2')
 
     assert inst1 != inst2
     assert inst2 == inst3
